@@ -13,9 +13,9 @@ class PageObject(PageObjectBase):
         self._name = name
 
         try:
-            self.parent.register_child(self)
-        except AttributeError:
-            pass
+            self.parent._register_child(self)
+        except AttributeError: # pragma: no cover
+            pass # we don't have a parent or the parent is not a PageObject
 
         self.init_children()
 
@@ -23,6 +23,8 @@ class PageObject(PageObjectBase):
     def __bool__(self):
         return self.is_existing(log=False)
 
+    __nonzero__ = __bool__ # Python 2 throwback
+
 
     def __getitem__(self, key):
         return self.children[key]
@@ -32,14 +34,15 @@ class PageObject(PageObjectBase):
         return len(self.children)
 
 
-    def register_child(self, child):
+    def _register_child(self, child):
         try:
+            assert isinstance(child, PageObjectBase)
             self.__setattr__(child.name, child)
-        except TypeError:
-            return
+        except TypeError: # pragma: no cover
+            pass # child has an invalid name
 
 
-    def init_children(self):
+    def init_children(self): # pragma: no cover
         """
         Meant to be overloaded by page objects
         containing other page objects.
