@@ -1,4 +1,5 @@
 import logging
+from selenium.webdriver import Remote as WebDriver
 
 
 class PageObjectBase(object):
@@ -22,16 +23,21 @@ class PageObjectBase(object):
         return None
 
 
+    @property
+    def _parent_locator(self):
+        try:
+            return self.parent.locator
+        except AttributeError:
+            return ''
+
+
     @property
     def locator(self):
         if self.default_locator:
             return self.default_locator
-        try:
-            if self._chain:
-                return self.parent.locator + self._locator
-            else:
-                return self._locator
-        except AttributeError:
+        elif self._chain:
+            return '{}{}'.format(self._parent_locator, self._locator)
+        else:
             return self._locator
 
 
@@ -40,6 +46,9 @@ class PageObjectBase(object):
         try:
             return self.parent.webdriver
         except AttributeError:
+            error_msg = ('webdriver should be an instance of selenium'
+                        + ' WebDriver, instead is "{}"').format(self._webdriver)
+            assert isinstance(self._webdriver, WebDriver), error_msg
             return self._webdriver
 
 
